import { Layout, LayoutRoot, Options } from 'react-native-navigation';
interface SetRootCommand {
    (layoutRoot: LayoutRoot): Promise<any>;
    (layout: Layout): Promise<any>;
    <P = {}>(name: string, passProps?: P, options?: Options): Promise<any>;
}
interface SetStackRootCommand {
    <P = {}>(layout: Layout<P> | Layout<P>[]): Promise<any>;
    <P = {}>(name: string, passProps?: P, options?: Options): Promise<any>;
}
interface PushCommand {
    <P = {}>(layout: Layout<P>): Promise<any>;
    (name: string): Promise<any>;
    <P = {}>(name: string, passProps?: P): Promise<any>;
    <P = {}>(name: string, passProps?: P, options?: Options): Promise<any>;
}
interface ShowModalCommand {
    (layout: Layout): Promise<any>;
    <P = {}>(name: string, passProps?: P, options?: Options): Promise<any>;
}
interface ShowOverlayCommand {
    (layout: Layout): Promise<any>;
    <P = {}>(name: string, passProps?: P, options?: Options): Promise<any>;
}
export declare type NavigationCommands = {
    setRoot: SetRootCommand;
    setStackRoot: SetStackRootCommand;
    push: PushCommand;
    showModal: ShowModalCommand;
    showOverlay: ShowOverlayCommand;
    mergeOptions: (options: Options) => void;
    updateProps: (props: object) => void;
    dismissModal: (mergeOptions?: Options) => Promise<any>;
    pop: (mergeOptions?: Options) => Promise<any>;
    popTo: (mergeOptions?: Options) => Promise<any>;
    popToRoot: (mergeOptions?: Options) => Promise<any>;
    dismissOverlay: () => Promise<any>;
    setDefaultOptions: (options: Options) => void;
    dismissAllModals: (mergeOptions?: Options) => Promise<any>;
    getLaunchArgs: () => Promise<any>;
};
/**
 * Creates a set of action helpers for
 * [component](https://wix.github.io/react-native-navigation/api/component),
 * [root](https://wix.github.io/react-native-navigation/api/root),
 * [stack](https://wix.github.io/react-native-navigation/api/stack),
 * [modal](https://wix.github.io/react-native-navigation/api/modal),
 * [overlay](https://wix.github.io/react-native-navigation/api/overlay)
 * Navigation API exposing multiple function types for the each function as a list of overloads.
 */
declare function createNavigationCommands(
/**
 * Component reference id. Used to give context to the Navigation functions that requires componentId parameter.
 */
componentId: string): NavigationCommands;
export default createNavigationCommands;
//# sourceMappingURL=createNavigationCommands.d.ts.map