"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var react_native_navigation_1 = require("react-native-navigation");
var createLayout_1 = __importDefault(require("./createLayout"));
/**
 * Creates a set of action helpers for
 * [component](https://wix.github.io/react-native-navigation/api/component),
 * [root](https://wix.github.io/react-native-navigation/api/root),
 * [stack](https://wix.github.io/react-native-navigation/api/stack),
 * [modal](https://wix.github.io/react-native-navigation/api/modal),
 * [overlay](https://wix.github.io/react-native-navigation/api/overlay)
 * Navigation API exposing multiple function types for the each function as a list of overloads.
 */
function createNavigationCommands(
/**
 * Component reference id. Used to give context to the Navigation functions that requires componentId parameter.
 */
componentId) {
    function setRoot(nameOrLayout, passProps, options) {
        var layoutRoot;
        if (typeof nameOrLayout === 'string') {
            layoutRoot = { root: createLayout_1.default(nameOrLayout, passProps, options) };
        }
        else if (nameOrLayout.root) {
            layoutRoot = nameOrLayout;
        }
        else {
            layoutRoot = { root: nameOrLayout };
        }
        return react_native_navigation_1.Navigation.setRoot(layoutRoot);
    }
    function setStackRoot(nameOrLayout, passProps, options) {
        var layout = typeof nameOrLayout === 'string' ? createLayout_1.default(nameOrLayout, passProps, options) : nameOrLayout;
        return react_native_navigation_1.Navigation.setStackRoot(componentId, layout);
    }
    function push(nameOrLayout, passProps, options) {
        var layout = typeof nameOrLayout === 'string' ? createLayout_1.default(nameOrLayout, passProps, options) : nameOrLayout;
        return react_native_navigation_1.Navigation.push(componentId, layout);
    }
    function showModal(nameOrLayout, passProps, options) {
        var layout = typeof nameOrLayout === 'string' ? createLayout_1.default(nameOrLayout, passProps, options) : nameOrLayout;
        return react_native_navigation_1.Navigation.showModal(layout);
    }
    function showOverlay(nameOrLayout, passProps, options) {
        var layout = typeof nameOrLayout === 'string' ? createLayout_1.default(nameOrLayout, passProps, options) : nameOrLayout;
        return react_native_navigation_1.Navigation.showOverlay(layout);
    }
    function mergeOptions(options) {
        return react_native_navigation_1.Navigation.mergeOptions(componentId, options);
    }
    function updateProps(props) {
        return react_native_navigation_1.Navigation.updateProps(componentId, props);
    }
    // eslint-disable-next-line no-shadow
    function dismissModal(mergeOptions) {
        return mergeOptions ? react_native_navigation_1.Navigation.dismissModal(componentId, mergeOptions) : react_native_navigation_1.Navigation.dismissModal(componentId);
    }
    // eslint-disable-next-line no-shadow
    function pop(mergeOptions) {
        return mergeOptions ? react_native_navigation_1.Navigation.pop(componentId, mergeOptions) : react_native_navigation_1.Navigation.pop(componentId);
    }
    // eslint-disable-next-line no-shadow
    function popTo(mergeOptions) {
        return mergeOptions ? react_native_navigation_1.Navigation.popTo(componentId, mergeOptions) : react_native_navigation_1.Navigation.popTo(componentId);
    }
    // eslint-disable-next-line no-shadow
    function popToRoot(mergeOptions) {
        return mergeOptions ? react_native_navigation_1.Navigation.popToRoot(componentId, mergeOptions) : react_native_navigation_1.Navigation.popToRoot(componentId);
    }
    function dismissOverlay() {
        return react_native_navigation_1.Navigation.dismissOverlay(componentId);
    }
    var setDefaultOptions = react_native_navigation_1.Navigation.setDefaultOptions, dismissAllModals = react_native_navigation_1.Navigation.dismissAllModals, getLaunchArgs = react_native_navigation_1.Navigation.getLaunchArgs;
    return {
        setRoot: setRoot,
        setStackRoot: setStackRoot,
        push: push,
        showModal: showModal,
        showOverlay: showOverlay,
        mergeOptions: mergeOptions,
        updateProps: updateProps,
        dismissModal: dismissModal,
        pop: pop,
        popTo: popTo,
        popToRoot: popToRoot,
        dismissOverlay: dismissOverlay,
        setDefaultOptions: setDefaultOptions,
        dismissAllModals: dismissAllModals,
        getLaunchArgs: getLaunchArgs,
    };
}
exports.default = createNavigationCommands;
//# sourceMappingURL=createNavigationCommands.js.map