"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var react_1 = require("react");
var contexts_1 = require("../contexts");
var createNavigationCommands_1 = __importDefault(require("../helpers/createNavigationCommands"));
/**
 * Returns a set of action helpers for
 * [component](https://wix.github.io/react-native-navigation/api/component),
 * [root](https://wix.github.io/react-native-navigation/api/root),
 * [stack](https://wix.github.io/react-native-navigation/api/stack),
 * [modal](https://wix.github.io/react-native-navigation/api/modal),
 * [overlay](https://wix.github.io/react-natwive-navigation/api/overlay)
 * Navigation API
 */
var useNavigation = function (
/**
 * Component reference id. Used to give context to the Navigation functions that requires componentId parameter.
 */
componentId) {
    var contextComponentId = react_1.useContext(contexts_1.NavigationContext).componentId;
    var id = componentId || contextComponentId;
    if (!id) {
        throw new Error('Missing "componentId". Use NavigationContext or pass "componentId" as argument.');
    }
    return react_1.useMemo(function () { return createNavigationCommands_1.default(id); }, [id]);
};
exports.default = useNavigation;
//# sourceMappingURL=useNavigation.js.map