"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var react_1 = require("react");
var react_native_navigation_1 = require("react-native-navigation");
/**
 * Registers listener to be called when a Navigation command (i.e push, pop, showModal etc) is invoked.
 * [more info](https://wix.github.io/react-native-navigation/api/events/#registercommandlistener)
 */
function useNavigationCommand(
/**
 * Function called each time the event is triggered.
 */
handler, 
/**
 * Component reference id. If provided it listens for event only for this screen.
 */
commandName) {
    react_1.useLayoutEffect(function () {
        var subscription = react_native_navigation_1.Navigation.events().registerCommandListener(function (name, params) {
            if (commandName && name !== commandName) {
                return;
            }
            handler(name, params);
        });
        return function () { return subscription.remove(); };
    }, [handler, commandName]);
}
exports.default = useNavigationCommand;
//# sourceMappingURL=useNavigationCommand.js.map