"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var react_1 = require("react");
var react_native_navigation_1 = require("react-native-navigation");
/**
 * Registers listener to be called when a command finishes executing in native. If the command contains
 * animations, for example pushed screen animation) the listener is invoked after the animation ends.
 * [more info]https://wix.github.io/react-native-navigation/api/events/#registercommandcompletedlistener)
 */
function useNavigationCommandComplete(
/**
 * Function called each time the event is triggered.
 */
handler, 
/**
 * Name of the executed navegation command. Ex. "push".
 */
commandName) {
    react_1.useLayoutEffect(function () {
        var subscription = react_native_navigation_1.Navigation.events().registerCommandCompletedListener(function (event) {
            if (commandName && event.commandName !== commandName) {
                return;
            }
            handler(event);
        });
        return function () { return subscription.remove(); };
    }, [handler, commandName]);
}
exports.default = useNavigationCommandComplete;
//# sourceMappingURL=useNavigationCommandComplete.js.map